@@ -1,21 +1,23 @@
 from javonet.core.handler.Handler import Handler
 from javonet.core.protocol.CommandDeserializer import CommandDeserializer
 from javonet.core.protocol.CommandSerializer import CommandSerializer
+from javonet.utils.ConnectionType import ConnectionType
 from javonet.utils.RuntimeName import RuntimeName
+from javonet.utils.TcpConnectionData import TcpConnectionData
 
 
 class Interpreter:
     response = None
 
-    def execute(self, command, connection_type, tcp_address):
+    def execute(self, command, connection_type, tcp_connection_data: TcpConnectionData):
         command_serializer = CommandSerializer()
-        serialized_command = command_serializer.serialize(command, connection_type, tcp_address)
-        if command.runtime_name == RuntimeName.python:
+        serialized_command = command_serializer.serialize(command, connection_type, tcp_connection_data)
+        if (command.runtime_name == RuntimeName.python) & (connection_type == ConnectionType.InMemory):
             from javonet.core.receiver.Receiver import Receiver
             response = Receiver().SendCommand(serialized_command, len(serialized_command))
         else:
-            from javonet.core.transmitter.PythonTransmitter import PythonTransmitter
-            response = PythonTransmitter.send_command(serialized_command)
+            from javonet.core.transmitter.Transmitter import Transmitter
+            response = Transmitter.send_command(serialized_command)
         command_deserializer = CommandDeserializer(response, len(response))
 
         return command_deserializer.deserialize()
