@@ -10,4 +10,7 @@ class Receiver:
         return bytearray(self.python_interpreter.process(messageByteArray, len(messageByteArray)))
 
     def HeartBeat(self, messageByteArray, messageByteArrayLen):
-        return bytearray([49, 48])
+        response_byte_array = bytearray(2)
+        response_byte_array[0] = messageByteArray[11]
+        response_byte_array[1] = messageByteArray[12] - 2
+        return response_byte_array
