@@ -1,12 +1,7 @@
-#!/usr/bin/perl
 package Javonet::Sdk::Core::RuntimeLib;
 use warnings;
 use strict;
-use Exporter;
-
-
-our @ISA = qw(Exporter);
-our @EXPORT = qw(get_runtime);
+use Moose;
 
 my %runtimes = (
     'Clr'       => 0,
@@ -25,4 +20,6 @@ sub get_runtime {
     return $runtimes{$runtime};
 }
 
+no Moose;
+
 1;
